<?php
if ( ! class_exists( 'IPProf_Factory' )) {

    /**
     * Class for create landing page
     */
    class IPProf_Factory
    {
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Render page
         *
         * @return string
         */
        public function render()
        {
            global $wp_query, $user_ID;
            if ( ( isset( $wp_query->query['ipprof'] ) && isset( $wp_query->query['profit_name'] ) ) || 
                 isset( $wp_query->query['profit_id'] ) ) 
            {
                $page = $wp_query->post;
                
                if ( $page->post_status == 'publish' ) 
                {
                    $setting = new IPProf_Setting( $page->ID, '__ipprof-setting' );
                    
                    $this->query     = $wp_query;
                    $this->setting   = $setting;
                    $this->page      = $page;
                    $this->basepath  = IPPROF_PATH . 'theme/';
                    $this->baseurl   = IPPROF_BASE_URL . 'theme/';
                    $this->cssurl    = $this->baseurl . 'css/';
                    $this->jsurl     = $this->baseurl . 'js/';
                    $this->imgurl    = $this->baseurl . 'img/';
                    $this->pageurl   = $this->get_page_link( $page );
                    $this->pagetitle = $this->get_page_title( $page );
                    
                    //Save stat
                    $this->_save_stat();
                    
                    //Include file template
                    $template = $this->_get_template();
                    include( $template );
                    exit();
                }
                else 
                {
                    $query->query_vars['post_type'] = 'ipprof-item-nothing';
                }
            }
        }
        
        /**
         * Get page link
         *
         * @param object $page
         * @return void
         */
        public function get_page_link( $page )
        {
            if ( get_option( 'permalink_structure' ) )  {
                $base = get_option( '__ipprof_base_path', 'profit' );
                $link = get_home_url() . "/$base/" . $page->post_name;
            } else {
                $link = get_home_url() . '/?profit_id=' . $page->ID;
            }
            return $link;
        }
        
        /**
         * Get page title
         *
         * @param object $page
         * @return void
         */
        public function get_page_title( $page )
        {
            $st    = $this->setting;
            $title = $st->getSetting( 'meta_title' );
            if ( empty( $title )) {
                $title = $st->getSetting( 'title', 'Contest' );
            }
            $title = stripslashes( $title );
            return $title;
        }
        
        /**
         * Inc
         *
         * @param  string $path
         * @param  string $exr
         * @return void
         */
        public function inc( $path, $ext = '.php' )
        {
            $path = IPPROF_PATH . 'theme/' . $path . $ext;
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get offers
         *
         * @param  int $paged
         * @return array
         */
        public function get_offers( $paged = 1 )
        {
            $perpage = $this->setting->getSetting( 'per_page', 20, true );
            if ( ! $perpage ) {
                $perpage = -1;
            }
            $args = array(
                'orderby'        => 'menu_order',
                'order'          => 'ASC', 
                'post_type'      => 'ipprof-offer-item',
                'post_status'    => array('publish','draft'),
                'posts_per_page' => $perpage,
                'paged'          => $paged,
                'post_parent'    => $this->page->ID
            );
            $query = new WP_Query;
            $this->_offers = $query->query( $args );
            return $this->_offers;
        }
        
        /**
         * Get more offers
         *
         * @param  array $page
         * @param  int   $paged
         * @return array
         */
        public function get_more_offers( $page, $paged )
        {
            $this->page    = $page;
            $this->setting = new IPProf_Setting( $page->ID, '__ipprof-setting' );
            if ( $offers = $this->get_offers( $paged )) 
            {
                $this->offers = $offers;
                $template = IPPROF_PATH . 'theme/offer/more.php';
                if ( file_exists( $template )) {
                    include( $template );
                    die();
                }
            } else {
                echo '';
            }
        }
        
        /**
         * Get Google font
         *
         * @return string
         */
        public function get_google_font()
        {
            $fonts   = array();
            $fonts[] = $this->setting->getSetting( 'top_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'top_content_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'main_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'footer_font_family', 'roboto' );
            $fonts   = array_unique( $fonts );
            
            $fams  = array();
            $links = IPProf_Font::getLinks();
            foreach( $fonts as $font ) 
            {
                if ( array_key_exists( $font, $links )) 
                {
                    $fams[] = $links[$font];
                }
            }
            
            $family  = implode( '|', $fams );
            $url     = 'http://fonts.googleapis.com/css?family=' . $family;
            return $url;
        }
        
        /**
         * Get share link
         *
         * @param  object $setting
         * @param  string $type
         * @return string
         */
        public function get_share_link( $setting, $type )
        {
            $pagetitle = urlencode( $setting->getSetting( 'offer_headline' ) );
            $pageurl   = urlencode( $setting->getSetting( 'offer_url' ) );
            $actions   =  array(
                'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
                'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
                'google-plus'   => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
                'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle
            );
            $link = '#';
            if ( array_key_exists( $type, $actions )) {
                $link = $actions[$type];
            }
            return $link;
        }
        
        /**
         * Fix youtube url
         *
         * @param  string $url
         * @return string
         */
        public function fix_youtube_url( $url )
        {
            if ( $url )
            {
                if ( strpos( $url, 'embed' ) === false ) {
                    if ( strpos( $url, 'watch' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['query'] )) {
                            parse_str( $parsed['query'], $args );
                            if ( ! empty( $args['v'] )) {
                                $id = $args['v'];
                            }
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['path'] )) {
                            $id = trim( $parsed['path'], '/' );
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    }
                }
                $url .= '?autoplay=1&rel=0';
            }
            return $url;
        }
        
        /**
         * Save stat
         *
         * @return void
         */
        protected function _save_stat()
        {
            $model = new IPProf_Model();
            $model->save_stat( $this->page, 'view' );
        }
        
        /**
         * Get page template
         *
         * @return void
         */
        protected function _get_template()
        {
            $template = IPPROF_PATH . 'theme/index.php';
            return $template;
        }
    }
}