<?php
if ( ! class_exists( 'IPProf_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPProf_Admin
    {
        /**
         * Show content admin home
         *
         * @return void
         */
        public function index()
        {
        ?>
            <div id="ipprof-dashboard" class="wrap ipbe-wrap ipprof-admin">
                <div class="ipbe-inner">
                    
                    <?php $this->_header( 'ipprof' ); ?>
                    
                    <div class="ipbe-main">
                        <div class="ipbe-main-info">
                            <?php
                            if ( isset( $_GET['create'] )) :
                            ?>
                            <div class="ipbe-alert ipbe-alert-success" style="display: block;">
                                <?php _e( 'Successfully add a profit page.', 'wp_profit_page_creator' ); ?>
                            </div>
                            <?php
                            elseif ( isset( $_GET['delete'] )) :
                            ?>
                            <div class="ipbe-alert ipbe-alert-success" style="display: block;">
                                <?php _e( 'Successfully deleting a profit page.', 'wp_profit_page_creator' ); ?>
                            </div>
                            <?php
                            endif;
                            ?>
                        </div>
                        
                        <div class="ipbe-primary">
                            <?php
                            $list = new IPProf_List();
                            $list->render();
                            ?>
                        </div>
                    </div>
                    
                </div>
                
            </div>
        <?php
        }
        
        /**
         * Show content admin add style
         *
         * @return void
         */
        public function add()
        {
            $this->manage();
        }
        
        /**
         * Show content admin edit style
         *
         * @return void
         */
        public function edit()
        {
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_profit_page_creator') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $style = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_profit_page_creator') );
            }
            $this->manage( $style );
        }
        
        /**
         * Show content admin manage profit page
         *
         * @return void
         */
        public function manage( $profit = false )
        {
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
            
            $profitId = 0;
            if ( $profit ) {
                $profitId = $profit->ID;
            }
            $setting     = new IPProf_Setting( $profitId, '__ipprof-setting' );
            $form_action = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipprof=1&action=ipprof_update';
            
            if ( $profit ) 
            {
                $pageTitle = __( 'Edit Profit Page', 'wp_profit_page_creator' );
                $submit    = __( 'Save Change', 'wp_profit_page_creator' );
                $submitId  = 'ipprof-edit-profit';
                $formId    = 'ipprof-form-update';
                $submit_icon = 'floppy-o';
                
            } else 
            {
                $pageTitle = __( 'Add Profit Page', 'wp_profit_page_creator' );
                $submit    = __( 'Add Profit Page', 'wp_profit_page_creator' );
                $submitId  = 'ipprof-add-profit';
                $formId    = 'ipprof-form-add';
                $submit_icon = 'plus-circle';
            }
            
            $tab = 'ipprof-section-general';
            if ( ! empty( $_REQUEST['tab'] )) {
                $tab = $_REQUEST['tab'];
            }
        ?>
            <div id="ipprof-manage" class="wrap ipbe-wrap ipprof-admin">
                <div class="ipbe-inner">
                    <?php 
                    if ( $profit ) 
                    {
                        $title = $profit->post_title;
                        $info  = '<i class="ibe ibe-calendar"></i> Created: <strong>' . mysql2date( 'd F Y, h:i', $profit->post_date ) . '</strong>';
                        $icon  = 'pencil';
                        $this->_header( 'ipprof', $title, $info, $icon );
                    } else {
                        $this->_header( 'ipprof-add' );
                    }
                    ?>
                    <div class="ipbe-main">
                        <div class="ipbe-main-info"></div>
                        
                        <div class="ipbe-primary">
                            <div class="ipbe-manage-wrap ipbe-manage-sidebar">
                            <form enctype="multipart/form-data" id="<?php echo $formId; ?>" method="post" class="ipbe-form ip-form-cont" action="<?php echo $form_action; ?>">
                                <input type="hidden" name="profit_id" id="ipprof-value-profitid" value="<?php echo $profitId; ?>" />
                                
                                <div class="container-fluid container">
                                    <div class="ipbe-clear ipbe-tab">
                                        <div class="ipbe-sidebar">
                                            <div class="ipbe-sidebar-inner">
                                                <input type="hidden" name="tab_selected" id="ipbe-tab-selected" value="<?php echo $tab; ?>" />
                                                <ul class="ipbe-page-menu ipbe-tab-menu">
                                                    <li>
                                                        <a href="#ipprof-section-general" class="active">
                                                            <i class="ibe ibe-cogs"></i>
                                                            <strong><?php _e( 'General', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <?php
                                                    if ( $profit ) :
                                                    ?>
                                                    <li>
                                                        <a href="#ipprof-section-offer">
                                                            <i class="ibe ibe-star"></i>
                                                            <strong><?php _e( 'Offers', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-header-footer">
                                                            <i class="ibe ibe-columns"></i>
                                                            <strong><?php _e( 'Header and Footer', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-content">
                                                            <i class="ibe ibe-file-o"></i>
                                                            <strong><?php _e( 'Top Content', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-design">
                                                            <i class="ibe ibe-paint-brush"></i>
                                                            <strong><?php _e( 'Design', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-share">
                                                            <i class="ibe ibe-share-alt"></i>
                                                            <strong><?php _e( 'Share', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-seo">
                                                            <i class="ibe ibe-globe"></i>
                                                            <strong><?php _e( 'SEO', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-script">
                                                            <i class="ibe ibe-plug"></i>
                                                            <strong><?php _e( 'Script', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <li>
                                                        <a href="#ipprof-section-statistic">
                                                            <i class="ibe ibe-line-chart"></i>
                                                            <strong><?php _e( 'Statistic', 'wp_profit_page_creator' ); ?></strong>
                                                        </a>
                                                    </li>
                                                    <?php
                                                    endif;
                                                    ?>
                                                </ul>
                                            </div>
                                        </div>
                                        <div class="ipbe-manage-content">
                                        
                                            <div class="ipbe-manage-info">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="ipbe-tab-title">
                                                            <i class="ibe ibe-cogs"></i>
                                                            <div class="ipbe-title-text">
                                                                <h3><?php _e( 'General', 'wp_profit_page_creator' ); ?></h3>
                                                                <p><?php _e( 'Basic settings and info of your profit page', 'wp_profit_page_creator' ); ?></p>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="ipbe-top-submit">
                                                            <button type="submit" class="ip-form-submit ipbe-btn ipbe-btn-primary ipbe-btn-lg <?php echo $submitId; ?>" id="do-update-top" name="update_top">
                                                                <i class="ibe ibe-<?php echo $submit_icon; ?>"></i>
                                                                <strong><?php echo $submit; ?></strong>
                                                            </button>
                                                            <?php
                                                            if ( $profit ) {
                                                                echo '<p class="ipbe-update-info">' .
                                                                        __( 'Last Update', 'wp_profit_page_creator' ) .
                                                                        ': <strong>' . mysql2date( 'd F Y, h:i:s', $profit->post_date ) . '</strong>' .
                                                                      '</p>';
                                                            }
                                                            ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="ipbe-tab-contents">
                                                <?php
                                                //Main Info
                                                $this->_tab_general( $profit, $setting );
                                                
                                                if ( $profit ) {
                                                    //Offers
                                                    $this->_tab_offer( $profit, $setting );
                                                    //Header & Footer
                                                    $this->_tab_header_footer( $profit, $setting );
                                                    //Top Content
                                                    $this->_tab_content( $profit, $setting );
                                                    //Design
                                                    $this->_tab_design( $profit, $setting );
                                                    //Share
                                                    $this->_tab_share( $profit, $setting );
                                                    //SEO
                                                    $this->_tab_seo( $profit, $setting );
                                                    //Script
                                                    $this->_tab_script( $profit, $setting );
                                                    //Statistic
                                                    $this->_tab_statistic( $profit, $setting );
                                                }
                                                ?>
                                            </div>
                                            
                                            <div class="ipbe-manage-footer">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="ipbe-bottom-submit">
                                                            <button type="submit" class="ip-form-submit ipbe-btn ipbe-btn-primary ipbe-btn-lg <?php echo $submitId; ?>" id="do-update-bottom" name="update_bottom">
                                                                <i class="ibe ibe-<?php echo $submit_icon; ?>"></i>
                                                                <strong><?php echo $submit; ?></strong>
                                                            </button>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="ipbe-bottom-action text-right">
                                                            <?php
                                                            if ( $profit ) :
                                                            ?>
                                                            <a href="<?php echo $this->_get_link_view( $profit ); ?>" class="ipbe-btn ipbe-btn-success ipbe-btn-lg" target="_blank">
                                                                <i class="ibe ibe-eye"></i>
                                                                <?php _e( 'View Page', 'wp_profit_page_creator' ); ?>
                                                            </a>
                                                            <?php
                                                            endif;
                                                            ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            
                            </form>
                            </div>
                        </div>
                    </div>
                    
                </div>
                
                <div id="ipprof-modal-add-offer" class="ipbe-ui-modal" style="display:none;">
                    <div class="ipbe-ui-modal-main">
                        <div class="ipbe-ui-modal-inner">
                            <div class="ipbe-ui-modal-title">
                                <h3><?php _e( 'Add New Offer', 'wp_profit_page_creator' ); ?></h3>
                                <div class="ipbe-ui-close">
                                    <a href="#"><i class="ibe ibe-times-circle"></i></a>
                                </div>
                            </div>
                            <div class="ipbe-ui-modal-content">
                                <?php
                                $action = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipprof=1&action=ipprof_offer_update';
                                ?>
                                <form id="ipprof-add-offer-form" method="post" class="ipbe-form ip-form-cont" action="<?php echo $action; ?>" enctype="multipart/form-data">
                                    <div class="container-fluid container">
                                    <?php
                                    $this->offer_form();
                                    ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
                
                <div id="ipprof-modal-edit-offer" class="ipbe-ui-modal" style="display:none;">
                    <div class="ipbe-ui-modal-main">
                        <div class="ipbe-ui-modal-inner">
                            <div class="ipbe-ui-modal-title">
                                <h3><?php _e( 'Edit Offer', 'wp_profit_page_creator' ); ?></h3>
                                <div class="ipbe-ui-close">
                                    <a href="#"><i class="ibe ibe-times-circle"></i></a>
                                </div>
                            </div>
                            <div class="ipbe-ui-modal-content">
                                <?php
                                $form_action = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipprof=1&action=ipprof_offer_update';
                                ?>
                                <form id="ipprof-edit-offer-form" method="post" class="ipbe-form ip-form-cont" action="<?php echo $form_action; ?>" enctype="multipart/form-data">
                                    <div class="container-fluid container ipprof-edit-modal-main">
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
                
            </div>
            
        <?php
        }
        
        /**
         * Get link view
         *
         * @param  object $item
         * @return string
         */
        protected function _get_link_view( $item )
        {
            $home = get_home_url();
            $base = get_option( '__ipprof_base_path', 'profit' );
            
            if ( get_option( 'permalink_structure' ) )  {
                $link = $home . "/$base/" . $item->post_name;
            } else {
                $link = $home . '/?profit_id=' . $item->ID . '&ipprof=1';
            }
            
            return $link;
        }
        
        /**
         * Tab general
         *
         * @return void
         */
        protected function _tab_general( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-general" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-cogs"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'General', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Basic settings and info of your profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        <div class="ipbe-field-row ipbe-field-y ipbe-help-abs">
                            <div class="ipbe-form-label">
                                <label for="input-name"><?php _e( 'Page Name', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field">
                                <?php
                                $name = '';
                                if ( $profit ) {
                                    $name = stripslashes( $profit->post_title );
                                }
                                ?>
                                <input type="text" id="input-name" class="ipbe-input ipbe-input-full ipbe-input-v-lg" name="name" value="<?php echo $name; ?> ">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'The name of the profit page. This data will not be used directly in shaping the profit page, only to mark the profit page, so it easier for you to manage it.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-permalink"><?php _e( 'Permalink', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                <?php
                                $slug  = '';
                                if ( $profit ) {
                                    $slug = stripslashes( $profit->post_name );
                                }
                                ?>

                                <span class="ipprof-input-permalink">
                                    <strong class="italic font-h4 color-grey"><?php echo $this->_get_permalink_root(); ?></strong>
                                    <input type="text" id="input-permalink" class="ipbe-input ipbe-input-md" name="slug" value="<?php echo $slug; ?>">
                                </span>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the structure of a link from the profit page. You can ignore this because it will be set directly by the system based on page name.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-status"><?php _e( 'Status', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <div class="ipbe-btn-onoff">
                                    <?php
                                    $val  = 'true';
                                    if ( $profit && $profit->post_status == 'draft' ) {
                                        $val = 'false';
                                    }
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'Publish', 'wp_profit_page_creator' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Draft', 'wp_profit_page_creator' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="status" value="<?php echo $val; ?>" />
                                </div>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the status of the profit page whether the page will be viewable by the public or not. If set to draft the URL to access the page will generate an error page not found.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-restricted"><?php _e( 'Restricted User', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <div class="ipbe-btn-onoff">
                                    <?php
                                    $val = $setting->getSetting( 'restricted', 'false' );
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_profit_page_creator' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_profit_page_creator' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="restricted" value="<?php echo $val; ?>" />
                                </div>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Decides whether to tighten the profit page where only logged-in user can view the page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php
                        //Offer per page
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-per-page"><?php _e( 'Offers Per Page', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-per-page" class="ipbe-input ipbe-input-sm" name="per_page" value="<?php echo stripslashes( $setting->getSetting( 'per_page', 20 )); ?>">
                                <em class="ipbe-info ml10"><?php _e( 'Set to 0 if you want to display all the data offers', 'wp_profit_page_creator' ); ?></em>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the number of offers that offers displayed on each page. If the data is greater than the value of this option, the other data is displayed automatically when the user scrolling the page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Get permalink root
         *
         * @return string
         */
        protected function _get_permalink_root()
        {
            $home = get_home_url();
            $path = get_option( '__ipprof_base_path', 'profit' );
            $root = $home . '/' . $path . '/';
            return $root;
        }
        
        /**
         * Tab email
         *
         * @return void
         */
        protected function _tab_header_footer( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-header-footer" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-columns"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Header and Footer', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Setting for header and footer content in profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        <?php
                        //Site Header
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-site-header"><?php _e( 'Site Header', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                <?php
                                $imgdsp   = '';
                                $texdsp   = '';
                                $selected = $setting->getSetting( 'site_header', 'title' );
                                if ( $selected == 'image' ) {
                                    $imgdsp = ' checked="checked"';
                                } else {
                                    $texdsp = ' checked="checked"';
                                }
                                ?>
                                <div class="ipbe-field-textimg ipbe-radio-select">
                                    <div class="ipbe-field-text">
                                        <div class="ipbe-radio-input">
                                            <label>
                                                <input class="ipbe-trigger" type="radio" name="site_header" value="title"<?php echo $texdsp; ?> />
                                                <?php _e( 'Use Text' , 'wp_profit_page_creator'); ?>
                                            </label>
                                            <div class="ipbe-content mt5">
                                                
                                <input type="text" class="ipbe-input ipbe-input-full" name="site_header_text" value="<?php echo stripslashes( $setting->getSetting( 'site_header_text', '' )); ?>">
                                
                                            </div>
                                        </div>
                                    </div>
                                    <div class="ipbe-field-img line-space-top">
                                        <div class="ipbe-radio-input">
                                            <label>
                                                <input class="ipbe-trigger" type="radio" name="site_header" value="image"<?php echo $imgdsp; ?> />
                                                <?php _e( 'Use Image' , 'wp_profit_page_creator'); ?>
                                            </label>
                                            <div class="ipbe-content">
                                                
            <div class="ipbe-upload-image ipbe-clear">
                <div class="ipbe-upload-preview">
                    <?php
                    $setimg = false;
                    if ( $setting ) {
                        if ( $attach_id = $setting->getSetting( 'site_header_image' ) ) {
                            $setimg = true;
                            $data   = wp_get_attachment_image_src( $attach_id, 'thumbnail' );
                        }
                    }
                    if ( $setimg ) {
                        echo '<div class="image"><img src="' . $data[0] . '" /></div>';
                        echo '<div class="none ipbe-hide">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = '';
                    } else {
                        echo '<div class="image"></div>';
                        echo '<div class="none">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = ' style="display:none;"';
                    }
                    ?>
                </div>
                
                <div class="ipbe-image-field">
                    <div class="ipbe-select-image">
                        <p class="mt0"><?php _e( 'Select an image or upload new image using the button below.', 'wp_profit_page_creator' ); ?></p>
                        <a class="ipbe-btn ipbe-btn-primary ipbe-btn-media ipbe-btn-sm" name="select_image" data-choose="<?php esc_attr_e( 'Choose Preview Content Image' ); ?>"
                          data-update="<?php esc_attr_e( 'Choose image' ); ?>">
                            <i class="ibe ibe-image"></i>
                            <?php _e( 'Select Image', 'wp_profit_page_creator' ); ?>
                        </a>
                        <a class="ipbe-btn ipbe-btn-reset ipbe-btn-sm" href="#"<?php echo $reset_dsp; ?>>
                            <i class="ibe ibe-ban"></i>
                            <?php _e( 'Clear Image', 'wp_profit_page_creator' ); ?>
                        </a>
                    </div>
                    <input type="hidden" name="upload_type" class="ipbe-upload-type" value="site_header_image" />
                    <input type="hidden" name="site_header_image" class="ipbe-image-id" value="<?php echo $attach_id; ?>" />
                </div>
            </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the header of the profit page. Here you can define headers as plain text or images, which usually is the logo of the company / organization.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Header link
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-header-link"><?php _e( 'Header Link', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-header-link" class="ipbe-input ipbe-input-full" name="header_link" value="<?php echo $setting->getSetting( 'header-link' ); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the link from the header. You can mengkosongkan this data if it does not want to use the link.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Main Menu
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-main-menu"><?php _e( 'Main Menu', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-btn-onoff">
                                    <?php
                                    $val = $setting->getSetting( 'main_menu_status', 'false' );
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_share_it_now' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_share_it_now' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="main_menu_status" value="<?php echo $val; ?>" />
                                </div>
                                <select name="main_menu" class="ipprof-input-menu ipbe-input ml10">
                                
                                    <option value="0">
                                        <?php printf( '&mdash; %s &mdash;', esc_html__( 'Select a Menu' ) ); ?>
                                    </option>
                                    <?php
                                    $current  = absint( $setting->getSetting( 'main_menu', 0 ) );
                                    $nav_menus = wp_get_nav_menus( array('orderby' => 'name') );
                                    foreach( $nav_menus as $menu ) {
                                        $menu_id   = $menu->term_id;
                                        $menu_name = wp_html_excerpt( $menu->name, 40, '&hellip;' );
                                        $sltd      = '';
                                        if ( $menu_id == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $menu_id . '"' . $sltd . '>' . $menu_name . '</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the menu of the profit page that will be put at the top of the page. Here you just choose one of the menus that you created earlier in the Appearance &gt; Menus.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer Text
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-text"><?php _e( 'Footer Text', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-editor">
                                    <?php
                                    $tinymceInit = array(
                                        'editor_height' => 60
                                    );
                                    $content = stripslashes( $setting->getSetting( 'footer_text', '' ));
                                    wp_editor( $content, 'footer_text', array( 
                                        'editor_height' => 60,
                                        'tinymce'       => $tinymceInit
                                    )); 
                                    ?>
                                </div>
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text that is placed at the bottom of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer Menu
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-menu"><?php _e( 'Footer Menu', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-btn-onoff">
                                    <?php
                                    $val = $setting->getSetting( 'footer_menu_status', 'false' );
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_share_it_now' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_share_it_now' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="footer_menu_status" value="<?php echo $val; ?>" />
                                </div>
                                <select name="footer_menu" class="ipprof-input-menu ipbe-input ml10">
                                
                                    <option value="0">
                                        <?php printf( '&mdash; %s &mdash;', esc_html__( 'Select a Menu' ) ); ?>
                                    </option>
                                    <?php
                                    $current   = absint( $setting->getSetting( 'footer_menu', 0 ) );
                                    $nav_menus = wp_get_nav_menus( array('orderby' => 'name') );
                                    foreach( $nav_menus as $menu ) {
                                        $menu_id   = $menu->term_id;
                                        $menu_name = wp_html_excerpt( $menu->name, 40, '&hellip;' );
                                        $sltd      = '';
                                        if ( $menu_id == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $menu_id . '"' . $sltd . '>' . $menu_name . '</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the menu of the profit page that will be put at the bottom of the page. Here you just choose one of the menus that you created earlier in the Appearance &gt; Menus.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab Content
         *
         * @return void
         */
        protected function _tab_content( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-content" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-file-o"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Top Content', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Set all contents of your profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        <?php
                        //Title
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-title"><?php _e( 'Title', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-title" class="ipbe-input ipbe-input-full" name="title" value="<?php echo stripslashes( $setting->getSetting( 'title', '' )); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the title of the top content section.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Sub Title
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-subtitle"><?php _e( 'Sub Title', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-subtitle" class="ipbe-input ipbe-input-full" name="subtitle" value="<?php echo stripslashes( $setting->getSetting( 'subtitle', '' )); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the sub title of the top content section.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Info
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-info"><?php _e( 'Info', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-editor">
                                    <?php
                                    $tinymceInit = array(
                                        'editor_height' => 60
                                    );
                                    $content = stripslashes( $setting->getSetting( 'info', '' ) );
                                    wp_editor( $content, 'info', array( 
                                        'editor_height' => 60,
                                        'tinymce'       => $tinymceInit
                                    )); 
                                    ?>
                                </div>
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the info of the top content section.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Preview Content
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-preview-content"><?php _e( 'Preview Content', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                <?php
                                $imgdsp   = '';
                                $viddsp   = '';
                                $selected = $setting->getSetting( 'preview_content', 'image' );
                                if ( $selected == 'image' ) {
                                    $imgdsp = ' checked="checked"';
                                } else {
                                    $viddsp = ' checked="checked"';
                                }
                                ?>
                                <div class="ipbe-field-imgvid ipbe-radio-select">
                                    <div class="ipbe-field-img line-space-bottom">
                                        <div class="ipbe-radio-input">
                                            <label>
                                                <input class="ipbe-trigger" type="radio" name="preview_content" value="image"<?php echo $imgdsp; ?> />
                                                <?php _e( 'Use Image' , 'wp_profit_page_creator'); ?>
                                            </label>
                                            <div class="ipbe-content">
                                                
            <div class="ipbe-upload-image ipbe-clear">
                <div class="ipbe-upload-preview">
                    <?php
                    $setimg = false;
                    if ( $setting ) {
                        if ( $attach_id = $setting->getSetting( 'preview_content_image' ) ) {
                            $setimg = true;
                            $data   = wp_get_attachment_image_src( $attach_id, 'thumbnail' );
                        }
                    }
                    if ( $setimg ) {
                        echo '<div class="image"><img src="' . $data[0] . '" /></div>';
                        echo '<div class="none ipbe-hide">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = '';
                    } else {
                        echo '<div class="image"></div>';
                        echo '<div class="none">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = ' style="display:none;"';
                    }
                    ?>
                </div>
                
                <div class="ipbe-image-field">
                    <div class="ipbe-select-image">
                        <p class="mt0"><?php _e( 'Select an image or upload new image using the button below.', 'wp_profit_page_creator' ); ?></p>
                        <a class="ipbe-btn ipbe-btn-primary ipbe-btn-media ipbe-btn-sm" name="select_image" data-choose="<?php esc_attr_e( 'Choose Preview Content Image' ); ?>"
                          data-update="<?php esc_attr_e( 'Choose image' ); ?>">
                            <i class="ibe ibe-image"></i>
                            <?php _e( 'Select Image', 'wp_profit_page_creator' ); ?>
                        </a>
                        <a class="ipbe-btn ipbe-btn-reset ipbe-btn-sm" href="#"<?php echo $reset_dsp; ?>>
                            <i class="ibe ibe-ban"></i>
                            <?php _e( 'Clear Image', 'wp_profit_page_creator' ); ?>
                        </a>
                    </div>
                    <input type="hidden" name="upload_type" class="ipbe-upload-type" value="preview_content_image" />
                    <input type="hidden" name="preview_content_image" class="ipbe-image-id" value="<?php echo $attach_id; ?>" />
                </div>
            </div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="ipbe-field-vid">
                                        <div class="ipbe-radio-input">
                                            <label>
                                                <input class="ipbe-trigger" type="radio" name="preview_content" value="video"<?php echo $viddsp; ?> />
                                                <?php _e( 'Use Video' , 'wp_profit_page_creator'); ?>
                                            </label>
                                            <div class="ipbe-content mt5">
                                                
                                <input type="text" class="ipbe-input ipbe-input-full" name="preview_content_video" value="<?php echo $setting->getSetting( 'preview_content_video', '' ); ?>" placeholder="<?php _e( 'Insert youtube video url' , 'wp_profit_page_creator'); ?>">
                                
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the image / video will be placed in top content section.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab Offers
         *
         * @return void
         */
        protected function _tab_offer( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-offer" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-star"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Offers', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Manage offers content for your profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="mb20">
                        <?php
                        /*
                        $add_ajax = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipprof=1&action=ipprof_add_offer_form';
                        ?>
                        <a href="<?php echo $add_ajax; ?>" id="ipprof-add-offer" data-modal-id="ipprof-modal-offer" class="ipbe-btn ipbe-btn-success">
                            <i class="ibe ibe-plus-circle"></i>
                            <?php _e( 'Add New Offer', 'wp_profit_page_creator' ); ?>
                        </a>
                        */
                        ?>
                        <a href="#ipprof-modal-add-offer" id="ipprof-add-offer" class="ipbe-btn ipbe-btn-success">
                            <i class="ibe ibe-plus-circle"></i>
                            <?php _e( 'Add New Offer', 'wp_profit_page_creator' ); ?>
                        </a>
                    </div>
                    
                    <div id="ipprof-manage-offers">
                        <?php
                        $list = new IPProf_List_Offer( $profit->ID );
                        $list->render();
                        ?>
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab Design
         *
         * @return void
         */
        protected function _tab_design( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-design" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-paint-brush"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Design Settings', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Set the appearance of profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        
                        <?php
                        //Top Style
                        ?>
                        <h3 class="ipbe-field-title">
                            <?php _e( 'Top Style', 'wp_profit_page_creator' ); ?>
                        </h3>
                        
                        <?php
                        //Header Style
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-header-style"><?php _e( 'Header Style', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select id="input-header-style" name="header_style">
                                    <option value="0"><?php printf( '&mdash; %s &mdash;', esc_html__( 'Select a Style' ) ); ?></option>
                                    <?php
                                    $current = absint( $setting->getSetting( 'header_style', 1 ) );
                                    $styles  = range(1,3);
                                    foreach( $styles as $key ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>Style #'. $key.'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the style header section (top of page) of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Text Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-text-color"><?php _e( 'Text Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-top-text-color" name="top_text_color" value="<?php echo $setting->getSetting( 'top_text_color', '#eeeeee' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text color of the header section (top of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Background Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-bg-color"><?php _e( 'Background Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-top-bg-color" name="top_bg_color" value="<?php echo $setting->getSetting( 'top_bg_color', '#444444' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the background color of the header section (top of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Menu Style
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-menu-style"><?php _e( 'Menu Style', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select name="top_menu_style" id="input-top-menu-style">
                                    <?php
                                    $current = $setting->getSetting( 'top_menu_style', 'text' );
                                    $styles  = array(
                                        'text'          => __( 'Text', 'wp_profit_page_creator' ),
                                        'square'        => __( 'Square', 'wp_profit_page_creator' ),
                                        'rounded'       => __( 'Rounded', 'wp_profit_page_creator' ),
                                        'bordered'      => __( 'Bordered', 'wp_profit_page_creator' ),
                                        'bottom-line'   => __( 'Bottom Line', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the style of the menu placed in the header section (top of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Menu Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-menu-color"><?php _e( 'Menu Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select name="top_menu_color" id="input-top-menu-color">
                                    <?php
                                    $current = $setting->getSetting( 'top_menu_color', 'white' );
                                    $styles  = array(
                                        'white'      => __( 'White', 'wp_profit_page_creator' ),
                                        'black'      => __( 'Black', 'wp_profit_page_creator' ),
                                        'grey'       => __( 'Grey', 'wp_profit_page_creator' ),
                                        'green'      => __( 'Green', 'wp_profit_page_creator' ),
                                        'blue'       => __( 'Blue', 'wp_profit_page_creator' ),
                                        'light-blue' => __( 'Light Blue', 'wp_profit_page_creator' ),
                                        'red'        => __( 'Red', 'wp_profit_page_creator' ),
                                        'orange'     => __( 'Orange', 'wp_profit_page_creator' ),
                                        'yellow'     => __( 'Yellow', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the color of the menu placed in the header section (top of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Font Family
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-font-family"><?php _e( 'Font Family', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                    <?php
                                    $current = stripslashes( $setting->getSetting( 'top_font_family', 'roboto' ) );
                                    $fonts   = IPProf_Font::getOptions();
                                    $fname   = IPProf_Font::getFontName( $current );
                                    ?>
                                    <span class="ipbe-font-family">
                                        <div class="ipbe-menu ipbe-fancy-option">
                                            <div class="ipbe-selected">
                                                <div class="ipbe-selected-box">
                                                <span data-select="<?php echo $current; ?>"><?php echo $fname; ?></span>
                                                </div>
                                                <span class="toggle"></span>
                                            </div>
                                            <div class="ipbe-select" style="display: none;">
                                                <div class="ipbe-select-content">
                                                <ul class="clearfix">
                                                    <?php 
                                                    foreach( $fonts as $key => $label ) :
                                                    ?>
                                                        <li data-select="<?php echo $key; ?>">
                                                            <strong class="ipbe-select-label">
                                                                <?php echo $label; ?>
                                                            </strong>
                                                        </li>
                                                    <?php
                                                    endforeach;
                                                    ?>
                                                </ul>
                                                </div>
                                            </div>
                                            <input type="hidden" name="top_font_family" class="ipbe-input-select" value="<?php echo $current; ?>" />
                                        </div>
                                    </span>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the font size for text in the header section (top of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Top Content Style
                        ?>
                        <h3 class="ipbe-field-title">
                            <?php _e( 'Top Content Style', 'wp_profit_page_creator' ); ?>
                        </h3>
                        
                        <?php
                        //Text Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-content-text-color"><?php _e( 'Text Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-top-content-text-color" name="top_content_text_color" value="<?php echo $setting->getSetting( 'top_content_text_color', '#333333' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text color of the top content section (bellow the header section).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Background Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-content-bg-color"><?php _e( 'Background Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-top-content-bg-color" name="top_content_bg_color" value="<?php echo $setting->getSetting( 'top_content_bg_color', '#aaaaaa' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the background color of the top content section (bellow the header section).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Font Family
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-top-content-font-family"><?php _e( 'Font Family', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                    <?php
                                    $current = stripslashes( $setting->getSetting( 'top_content_font_family', 'roboto' ) );
                                    $fonts   = IPProf_Font::getOptions();
                                    $fname   = IPProf_Font::getFontName( $current );
                                    ?>
                                    <span class="ipbe-font-family">
                                        <div class="ipbe-menu ipbe-fancy-option">
                                            <div class="ipbe-selected">
                                                <div class="ipbe-selected-box">
                                                <span data-select="<?php echo $current; ?>"><?php echo $fname; ?></span>
                                                </div>
                                                <span class="toggle"></span>
                                            </div>
                                            <div class="ipbe-select" style="display: none;">
                                                <div class="ipbe-select-content">
                                                <ul class="clearfix">
                                                    <?php 
                                                    foreach( $fonts as $key => $label ) :
                                                    ?>
                                                        <li data-select="<?php echo $key; ?>">
                                                            <strong class="ipbe-select-label">
                                                                <?php echo $label; ?>
                                                            </strong>
                                                        </li>
                                                    <?php
                                                    endforeach;
                                                    ?>
                                                </ul>
                                                </div>
                                            </div>
                                            <input type="hidden" name="top_content_font_family" class="ipbe-input-select" value="<?php echo $current; ?>" />
                                        </div>
                                    </span>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the font size for text in the top content section (bellow the header section).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer Style
                        ?>
                        <h3 class="ipbe-field-title">
                            <?php _e( 'Footer Style', 'wp_profit_page_creator' ); ?>
                        </h3>
                        
                        <?php
                        //Footer Style
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-style"><?php _e( 'Footer Style', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select id="input-footer-style" name="footer_style">
                                    <option value="0"><?php printf( '&mdash; %s &mdash;', esc_html__( 'Select a Style' ) ); ?></option>
                                    <?php
                                    $current = absint( $setting->getSetting( 'footer_style', 1 ) );
                                    $styles  = range(1,3);
                                    foreach( $styles as $key ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>Style #'. $key.'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the style footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer Text Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-text-color"><?php _e( 'Text Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-footer-text-color" name="footer_text_color" value="<?php echo $setting->getSetting( 'footer_text_color', '#aaaaaa' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text color of the footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer Background Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-bg-color"><?php _e( 'Background Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-footer-bg-color" name="footer_bg_color" value="<?php echo $setting->getSetting( 'footer_bg_color', '#222222' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the background color of the footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Menu Style
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-menu-style"><?php _e( 'Menu Style', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select name="footer_menu_style" id="input-footer-menu-style">
                                    <?php
                                    $current = $setting->getSetting( 'footer_menu_style', 'text' );
                                    $styles  = array(
                                        'text'          => __( 'Text', 'wp_profit_page_creator' ),
                                        'square'        => __( 'Square', 'wp_profit_page_creator' ),
                                        'rounded'       => __( 'Rounded', 'wp_profit_page_creator' ),
                                        'bordered'      => __( 'Bordered', 'wp_profit_page_creator' ),
                                        'bottom-line'   => __( 'Bottom Line', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the style of the menu placed in the footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Menu Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-menu-color"><?php _e( 'Menu Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select name="footer_menu_color" id="input-footer-menu-color">
                                    <?php
                                    $current = $setting->getSetting( 'footer_menu_color', 'white' );
                                    $styles  = array(
                                        'white'      => __( 'White', 'wp_profit_page_creator' ),
                                        'black'      => __( 'Black', 'wp_profit_page_creator' ),
                                        'grey'       => __( 'Grey', 'wp_profit_page_creator' ),
                                        'green'      => __( 'Green', 'wp_profit_page_creator' ),
                                        'blue'       => __( 'Blue', 'wp_profit_page_creator' ),
                                        'light-blue' => __( 'Light Blue', 'wp_profit_page_creator' ),
                                        'red'        => __( 'Red', 'wp_profit_page_creator' ),
                                        'orange'     => __( 'Orange', 'wp_profit_page_creator' ),
                                        'yellow'     => __( 'Yellow', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the color of the menu placed in the footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Font Family
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-font-family"><?php _e( 'Font Family', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                    <?php
                                    $current = stripslashes( $setting->getSetting( 'footer_font_family', 'roboto' ) );
                                    $fonts   = IPProf_Font::getOptions();
                                    $fname   = IPProf_Font::getFontName( $current );
                                    ?>
                                    <span class="ipbe-font-family">
                                        <div class="ipbe-menu ipbe-fancy-option">
                                            <div class="ipbe-selected">
                                                <div class="ipbe-selected-box">
                                                <span data-select="<?php echo $current; ?>"><?php echo $fname; ?></span>
                                                </div>
                                                <span class="toggle"></span>
                                            </div>
                                            <div class="ipbe-select" style="display: none;">
                                                <div class="ipbe-select-content">
                                                <ul class="clearfix">
                                                    <?php 
                                                    foreach( $fonts as $key => $label ) :
                                                    ?>
                                                        <li data-select="<?php echo $key; ?>">
                                                            <strong class="ipbe-select-label">
                                                                <?php echo $label; ?>
                                                            </strong>
                                                        </li>
                                                    <?php
                                                    endforeach;
                                                    ?>
                                                </ul>
                                                </div>
                                            </div>
                                            <input type="hidden" name="footer_font_family" class="ipbe-input-select" value="<?php echo $current; ?>" />
                                        </div>
                                    </span>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the font size for text in the footer section (bottom of page).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Main Style
                        ?>
                        <h3 class="ipbe-field-title">
                            <?php _e( 'Main Section Style', 'wp_profit_page_creator' ); ?>
                        </h3>
                        
                        <?php
                        //Main Background Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-main-bg-color"><?php _e( 'Background Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-main-bg-color" name="main_bg_color" value="<?php echo $setting->getSetting( 'main_bg_color', '#ffffff' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the background color of the main section (section displays a list of offer).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Main Text Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-main-text-color"><?php _e( 'Text Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-main-text-color" name="main_text_color" value="<?php echo $setting->getSetting( 'main_text_color', '#333333' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text color of the main section (section displays a list of offer).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Font Family
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-main-font-family"><?php _e( 'Font Family', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                    <?php
                                    $current = stripslashes( $setting->getSetting( 'main_font_family', 'roboto' ) );
                                    $fonts   = IPProf_Font::getOptions();
                                    $fname   = IPProf_Font::getFontName( $current );
                                    ?>
                                    <span class="ipbe-font-family">
                                        <div class="ipbe-menu ipbe-fancy-option">
                                            <div class="ipbe-selected">
                                                <div class="ipbe-selected-box">
                                                <span data-select="<?php echo $current; ?>"><?php echo $fname; ?></span>
                                                </div>
                                                <span class="toggle"></span>
                                            </div>
                                            <div class="ipbe-select" style="display: none;">
                                                <div class="ipbe-select-content">
                                                <ul class="clearfix">
                                                    <?php 
                                                    foreach( $fonts as $key => $label ) :
                                                    ?>
                                                        <li data-select="<?php echo $key; ?>">
                                                            <strong class="ipbe-select-label">
                                                                <?php echo $label; ?>
                                                            </strong>
                                                        </li>
                                                    <?php
                                                    endforeach;
                                                    ?>
                                                </ul>
                                                </div>
                                            </div>
                                            <input type="hidden" name="main_font_family" class="ipbe-input-select" value="<?php echo $current; ?>" />
                                        </div>
                                    </span>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the font size for text in the main section (section displays a list of offer).', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Box Offer Settings
                        ?>
                        <h3 class="ipbe-field-title">
                            <?php _e( 'Box Offer Settings', 'wp_profit_page_creator' ); ?>
                        </h3>
                        
                        <?php
                        //Style
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-style"><?php _e( 'Style', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <select id="input-box-style" name="box_style">
                                    <option value="0"><?php printf( '&mdash; %s &mdash;', esc_html__( 'Select a Style' ) ); ?></option>
                                    <?php
                                    $current = absint( $setting->getSetting( 'box_style', 1 ) );
                                    $styles  = range(1,6);
                                    foreach( $styles as $key ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>Style #'. $key.'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the style of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Background Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-bg-color"><?php _e( 'Background Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-box-bg-color" name="box_bg_color" value="<?php echo $setting->getSetting( 'box_bg_color', '#f6f6f6' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the background color of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Text Color
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-text-color"><?php _e( 'Text Color', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                            
                                <input type="text" class="ipprof-color-picker" id="input-box-text-color" name="box_text_color" value="<?php echo $setting->getSetting( 'box_text_color', '#555555' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the text color of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Border
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-border-status"><?php _e( 'Border', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-btn-onoff mr10">
                                    <?php
                                    $val = $setting->getSetting( 'box_border_status', 'true' );
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_profit_page_creator' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_profit_page_creator' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="box_border_status" value="<?php echo $val; ?>" />
                                </div>
                                
                                <?php
                                $width = absint( $setting->getSetting( 'box_border_width', 1 ));
                                ?>
                                <div class="ipbe-input-group mr5">
                                    <input type="text" id="input-box-border-width" class="ipbe-input ipbe-input-xs" name="box_border_width" value="<?php echo $width; ?>" placeholder="<?php _e( 'Width', 'wp_profit_page_creator' ); ?>">
                                    <div class="ipbe-input-addon">px</div>
                                </div>
                                
                                <select name="box_border_style" id="input-box-border-style mr5">
                                    <?php
                                    $current = $setting->getSetting( 'box_border_style', 'solid' );
                                    $styles  = array(
                                        'solid'   => __( 'Solid', 'wp_profit_page_creator' ),
                                        'dashed'  => __( 'Dashed', 'wp_profit_page_creator' ),
                                        'dotted'  => __( 'Dotted', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <input type="text" class="ipprof-color-picker" id="input-box-border-color" name="box_border_color" value="<?php echo $setting->getSetting( 'box_border_color', '#dddddd' ); ?>" />
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the border of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Box Shadow
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-shadow"><?php _e( 'Box Shadow', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <select name="box_shadow" id="input-box-shadow">
                                    <?php
                                    $current = $setting->getSetting( 'box_shadow', 'smooth' );
                                    $styles  = array(
                                        'none'    => __( 'None', 'wp_profit_page_creator' ),
                                        'smooth'  => __( 'Smooth', 'wp_profit_page_creator' ),
                                        'medium'  => __( 'Medium', 'wp_profit_page_creator' ),
                                        'rough'   => __( 'Rough', 'wp_profit_page_creator' )
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the box shadow of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Box Transparency
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-box-transparency"><?php _e( 'Box Transparency', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <select name="box_transparency" id="input-box-transparency">
                                    <?php
                                    $current = $setting->getSetting( 'box_transparency', 0 );
                                    $styles  = array(
                                        0   => __( 'None', 'wp_profit_page_creator' ),
                                        5   => '5%',
                                        10  => '10%',
                                        15  => '15%',
                                        20  => '20%',
                                        30  => '30%',
                                        40  => '40%',
                                        50  => '50%',
                                        75  => '75%'
                                    );
                                    foreach( $styles as $key => $label ) {
                                        $sltd = '';
                                        if ( $key == $current ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                                    }
                                    ?>
                                </select>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the box transperancy of the offer box.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab share
         *
         * @return void
         */
        protected function _tab_share( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-share" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-share-alt"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Share Settings', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Setting for share button in profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields ipbe-social-option">
                    
                        <?php
                        //Show share button
                        ?>
                        <div class="ipbe-field-row ipbe-field-x">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-share-status"><?php _e( 'Show Share Button', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <div class="ipbe-btn-onoff">
                                    <?php
                                    $val = $setting->getSetting( 'share_status', 'true' );
                                    if ( $val == 'false' ) {
                                        $clon  = '';
                                        $cloff = ' ipbe-btn-danger active';
                                    } else {
                                        $clon  = ' ipbe-btn-success active';
                                        $cloff = '';
                                    }
                                    ?>
                                    <div class="ipbe-btn-group">
                                        <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_profit_page_creator' ); ?></button>
                                        <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_profit_page_creator' ); ?></button>
                                    </div>
                                    <input type="hidden" class="ipbe-onoff-value" name="share_status" value="<?php echo $val; ?>" />
                                </div>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines whether to display the share button in each offer.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <div class="ipbe-field-row ipbe-field-y ipbe-help-abs">
                            <div class="ipbe-form-label mb10">
                                <label for="input-share-activate"><?php _e( 'Button Activate', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field">
                    
                                <p><?php _e( 'Select one or more share button that you want to display on the contest below.', 'wp_profit_page_creator' ); ?></p>
                                <div class="ipbe-social-active">
                                    <ul>
                                        <?php
                                        $social = array(
                                            'facebook'      => 'Facebook',
                                            'twitter'       => 'Twitter',
                                            'google-plus'   => 'Google+',
                                            'pinterest'     => 'Pinterest'
                                        );
                                        foreach( $social as $key => $label ) {
                                            $value = $setting->getSetting( 'share_'.$key, 'on' );
                                            $class = 'inactive';
                                            if ( $value == 'on' ) {
                                                $class = "active";
                                            }
                                            $icon = $key;
                                        ?>
                                            <li>
                                                <a class="<?php echo $class; ?>" href="#<?php echo $key; ?>">
                                                    <i class="ibe ibe-<?php echo $icon; ?>"></i>
                                                    <span><?php echo $label; ?></span>
                                                    <input type="hidden" name="share_<?php echo $key; ?>" value="<?php echo $value; ?>" />
                                                </a>
                                            </li>
                                        <?php
                                        }
                                        ?>
                                    </ul>
                                </div>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the share button which will be displayed in each offer.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                                
                            </div>
                        </div>
                    
                        <div class="ipbe-field-row ipbe-field-y ipbe-help-abs">
                            <div class="ipbe-form-label mb10">
                                <label for="input-share-button-icon"><?php _e( 'Button Icon', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field">
                            
                                <select name="share_button_icon" id="input-share-button-icon">
                                    <?php
                                    $icon    = $setting->getSetting( 'share_button_icon', 'square_flat' );
                                    $options = array(
                                        'square_flat'   => __( 'Square Flat', 'wp_profit_page_creator' ),
                                        'square_grad'   => __( 'Square Gradient', 'wp_profit_page_creator' ),
                                        'square_3d'     => __( 'Square 3D', 'wp_profit_page_creator' ),
                                        'square_shadow' => __( 'Square Shadow', 'wp_profit_page_creator' ),
                                        'round_flat'    => __( 'Round Flat', 'wp_profit_page_creator' ),
                                        'round_grad'    => __( 'Round Gradient', 'wp_profit_page_creator' ),
                                        'round_3d'      => __( 'Round 3D', 'wp_profit_page_creator' ),
                                        'round_shadow'  => __( 'Round Shadow', 'wp_profit_page_creator' )
                                    );
                                    foreach( $options as $no => $label ) {
                                        $sltd = '';
                                        if ( $no == $icon ) {
                                            $sltd = ' selected="selected"';
                                        }
                                        echo '<option value="' . $no . '"' . $sltd . '>' . $label . '</option>';
                                    }
                                    ?>
                                </select>
                                <h4 class="mb15"><?php _e( 'Preview','wp_profit_page_creator' ); ?></h4>
                                <div class="ipbe-icon-preview ipbe-clear">
                                        <?php
                                        $socials = array(
                                            'facebook',
                                            'twitter',
                                            'googleplus',
                                            'pinterest'
                                        );
                                        foreach( $socials as $name ) {
                                            $src = IPPROF_BASE_URL . 'img/icon/'.$icon.'/'.$name.'.png';
                                            echo '<span class="ipbe-icon"><img src="'.$src.'" alt="'.$name.'"></span>';
                                        }
                                        ?>
                                </div>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the style of the share button.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                                
                            </div>
                        </div>
                        
                    </div>
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab SEO
         *
         * @return void
         */
        protected function _tab_seo( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-seo" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-globe"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'SEO Settings', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Set SEO content for improve your profit page ranking in search engine', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        <?php
                        //Meta Title
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-meta-title"><?php _e( 'Meta Title', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-meta-title" class="ipbe-input ipbe-input-full" name="meta_title" value="<?php echo stripslashes( $setting->getSetting( 'meta_title' )); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the meta title of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Meta Description
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-meta-description"><?php _e( 'Meta Description', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-meta-description" class="ipbe-input ipbe-input-full" name="meta_description" value="<?php echo stripslashes( $setting->getSetting( 'meta_description' )); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the meta description of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Meta Keywords
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-meta-keywords"><?php _e( 'Meta Keywords', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-meta-keywords" class="ipbe-input ipbe-input-full" name="meta_keywords" value="<?php echo stripslashes( $setting->getSetting( 'meta_keywords' )); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the meta keywords of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Open graph image
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-ogimage"><?php _e( 'Open Graph Image URL', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-ogimage" class="ipbe-input ipbe-input-full" name="ogimage" value="<?php echo $setting->getSetting( 'ogimage' ); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the open graph image URL that will be used by the social website when the page is shared.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Favicon URL
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-favicon"><?php _e( 'Favicon URL', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <input type="text" id="input-favicon" class="ipbe-input ipbe-input-full" name="favicon" value="<?php echo $setting->getSetting( 'favicon' ); ?>">
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the favicon image url of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Tracking Code
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-tracking-code"><?php _e( 'Tracking Code', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <textarea id="input-tracking-code" class="ipbe-input ipbe-input-full" name="tracking_code" rows="6"><?php echo $setting->getSetting( 'tracking_code' ); ?></textarea>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Specifies the tracking code of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab script
         *
         * @return void
         */
        protected function _tab_script( $profit, $setting )
        {
        ?>
            <div id="ipprof-section-script" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-clock-o"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Script', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Set additional scripts for your profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">
                        <?php
                        //CSS Code
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-css-code"><?php _e( 'CSS Code', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <textarea id="input-css-code" class="ipbe-input ipbe-input-full" name="css_code" rows="6"><?php echo $setting->getSetting( 'css_code' ); ?></textarea>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the additional css code that will change the look of the profit page.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Head JS Code
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-head-js-code"><?php _e( 'Head Javascript Code', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <textarea id="input-head-js-code" class="ipbe-input ipbe-input-full" name="head_js_code" rows="6"><?php echo $setting->getSetting( 'head_js_code' ); ?></textarea>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the javascript code to be placed before the closing head tag.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php
                        //Footer JS Code
                        ?>
                        <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                            <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                                <label for="input-footer-js-code"><?php _e( 'Footer Javascript Code', 'wp_profit_page_creator' ); ?></label>
                            </div>
                            <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                                
                                <textarea id="input-footer-js-code" class="ipbe-input ipbe-input-full" name="footer_js_code" rows="6"><?php echo $setting->getSetting( 'footer_js_code' ); ?></textarea>
                                
                                <div class="ipbe-help">
                                    <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                                    <div class="ipbe-help-content ipbe-hide">
                                        <?php _e( 'Determines the javascript code to be placed before the closing body tag.', 'wp_profit_page_creator' ); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Tab statistic
         *
         * @return void
         */
        protected function _tab_statistic( $profit, $setting )
        {
            wp_enqueue_script('jquery-ui-datepicker');
        ?>
            <div id="ipprof-section-statistic" class="ipbe-tab-content">
                <div class="ipbe-tab-inner">
                    
                    <div class="ipbe-title-content ipbe-hide">
                        <i class="ibe ibe-line-chart"></i>
                        <div class="ipbe-title-text">
                            <h3><?php _e( 'Statistic', 'wp_profit_page_creator' ); ?></h3>
                            <p><?php _e( 'Statistics of user interaction to the profit page', 'wp_profit_page_creator' ); ?></p>
                        </div>
                    </div>
                    
                    <div class="ipbe-fields">


<?php
$model    = new IPProf_Model();
$pid      = $profit->ID;
$views    = $model->get_stat_value( $pid, 'view' );
$clicks   = $model->get_stat_value( $pid, 'click' );
$convRate = 0;
if( $clicks != '0' && $views != '0') {
    $convRate = 100 * intval($clicks) / intval($views);
    $convRate = round( $convRate, 2 );
}
?>
<div class="ipbe-admin-stat">
    <div class="ipbe-stat-filter ipbe-clear">
        <div class="ipbe-stat-nav">
            <div class="container container-fluid">
                <ul class="row">
                    <li class="col-sm-4 ipbe-nav-view active">
                        <a href="#stat-view">
                            <i class="ibe ibe-eye"></i>
                            <span class="stat-value">
                                <strong><?php echo number_format( $views ); ?></strong>
                                <em><?php _e( 'Views', 'wp_profit_page_creator' ); ?></em>
                            </span>
                        </a>
                    </li>
                    <li class="col-sm-4 ipbe-nav-click">
                        <a href="#stat-click">
                            <i class="ibe ibe-chain"></i>
                            <span class="stat-value">
                                <strong><?php echo number_format( $clicks ); ?></strong>
                                <em><?php _e( 'Clicks', 'wp_profit_page_creator' ); ?></em>
                            </span>
                        </a>
                    </li>
                    <li class="col-sm-4 ipbe-nav-ctr">
                        <a href="#stat-ctr">
                            <i class="ibe ibe-line-chart"></i>
                            <span class="stat-value">
                                <strong><?php echo $convRate; ?> %</strong>
                                <em><?php _e( 'CTR', 'wp_profit_page_creator' ); ?></em>
                            </span>
                        </a>
                    </li>
                </ul>
            </div>
        </div>
        <div class="ipbe-date-filter">
            <form action="" method="post">
                <input type="hidden" id="value-pageid" name="pageid" value="<?php echo $profit->ID; ?>" />
                <input type="hidden" id="value-stat-type" name="stat_type" value="view" />
                <?php
                $dateStart = date('m/d/Y');
                $dateEnd   = date('m/d/Y'); 
                ?>
                <strong><?php _e( 'Filter By Date', 'wp_profit_page_creator' ); ?>: </strong>
                <span class="ipbe-date-input">
                    <input type="text" id="date-start" name="cdatestart" value="<?php echo $dateStart; ?>" />
                    -
                    <input type="text" id="date-end" name="cdateend" value="<?php echo $dateEnd; ?>" />
                </span>
                <span class="ipbe-do-filter">
                    <input type="submit" id="do-filter-date" class="button button-primary" name="do_filter_date" value="<?php _e( 'Go', 'wp_profit_page_creator' ); ?>" />
                </span>
            </form>
        </div>
    </div>

    <div class="ipbe-stat-main">
        <h4><?php _e( 'Views Statistic', 'wp_profit_page_creator' ); ?></h4>
        <div class="ipbe-stat-chart">
        
            <script type="text/javascript" src="https://www.google.com/jsapi"></script>
            <script type="text/javascript">
                google.load("visualization", "1", {packages:["corechart"]});
                google.setOnLoadCallback(drawChart);
                function drawChart() {
                    
                    var dataTable = new google.visualization.DataTable();
                    dataTable.addColumn( 'date', '<?php _e( 'Date', 'wp_profit_page_creator' ); ?>' );
                    dataTable.addColumn( 'number', '<?php _e( 'Views', 'wp_profit_page_creator' ); ?>' );
                    
                    var rows = [
                    <?php
                    $stdata = $model->get_statistic_data( $profit->ID, 'view' );
                    if ( $stdata ) {
                        foreach( $stdata as $data ) {
                            $timestamp = strtotime( $data->gdate );
                            $phpdate   = getdate($timestamp);
                            
                            echo '[new Date(' 
                                    . $phpdate['year'] . ', '
                                    . ( $phpdate['mon']  - 1 ) . ', '
                                    . $phpdate['mday'] . ',0,0,0), '
                                    . $data->value
                                . '],';
                        }
                    }
                    ?>
                    ];
                    dataTable.addRows( rows );
                    
                    var options = {
                        series: [{pointSize:6}]
                    };
                    var chart = new google.visualization.LineChart(document.getElementById('ipprof-chart-div'));
                    chart.draw(dataTable, options);
                }
            </script>
            
            <div id="ipprof-chart-div" class="ipbe-chart-main" style="width: 100%; height: 500px;"></div>
            <div class="ipbe-chart-load" style="display: none;">
                <?php
                $plgurl = plugin_dir_url( dirname(__FILE__) );
                $src    = $plgurl . 'img/loading.gif';
                ?>
                <img src="<?php echo $src; ?>" alt="Loading..." />
            </div>
            
        </div>
    </div>
</div>

                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Get offer form
         *
         * @param  object $offer
         * @return void
         */
        public function offer_form( $offer = false )
        {
            $offerId = 0;
            if ( $offer ) {
                $offerId = $offer->ID;
            }
            $setting = new IPProf_setting( $offerId, '__ipprof-offer-setting' );
            if ( $offer ) 
            {
                $submit      = __( 'Save Change', 'wp_profit_page_creator' );
                $submitId    = 'ipprof-do-edit-offer';
                $submit_icon = 'floppy-o';
                
            } else 
            {
                $submit      = __( 'Add New Offer', 'wp_profit_page_creator' );
                $submitId    = 'ipprof-do-add-offer';
                $submit_icon = 'plus-circle';
            }
        ?>
        <div class="ipbe-fields">
            
            <input type="hidden" name="offer_id" id="ipprof-value-offerid" value="<?php echo $offerId; ?>" />
            
            <?php
            //Status
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-status"><?php _e( 'Status', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <div class="ipbe-btn-onoff">
                        <?php
                        $val = $setting->getSetting( 'offer_status', 'true' );
                        if ( $val == 'false' ) {
                            $clon  = '';
                            $cloff = ' ipbe-btn-danger active';
                        } else {
                            $clon  = ' ipbe-btn-success active';
                            $cloff = '';
                        }
                        ?>
                        <div class="ipbe-btn-group">
                            <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'Publish', 'wp_profit_page_creator' ); ?></button>
                            <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Draft', 'wp_profit_page_creator' ); ?></button>
                        </div>
                        <input type="hidden" class="ipbe-onoff-value" name="offer_status" value="<?php echo $val; ?>" />
                    </div>
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines the status of the offer if the data will be displayed on the page or not.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Headline
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-headline"><?php _e( 'Headline', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <?php
                    $title = '';
                    if ( $offer ) {
                        $title = stripslashes( $offer->post_title );
                    }
                    ?>
                    <input type="text" id="input-offer-headline" class="ipbe-input ipbe-input-full" name="offer_headline" value="<?php echo $title; ?>">
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines headline of the offer.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Thumbnail
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-thumbnail"><?php _e( 'Thumbnail', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <p class="mt0"><?php _e( 'Choose from your media library', 'wp_profit_page_creator' ); ?></p>

            <div class="ipbe-upload-image ipbe-clear mb20">
                <div class="ipbe-upload-preview">
                    <?php
                    $setimg = false;
                    if ( $setting ) {
                        if ( $attach_id = $setting->getSetting( 'offer_thumbnail_image' ) ) {
                            $setimg = true;
                            $data   = wp_get_attachment_image_src( $attach_id, 'thumbnail' );
                        }
                    }
                    if ( $setimg ) {
                        echo '<div class="image"><img src="' . $data[0] . '" /></div>';
                        echo '<div class="none ipbe-hide">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = '';
                    } else {
                        echo '<div class="image"></div>';
                        echo '<div class="none">' . __( 'No image', 'wp_profit_page_creator' ) . '</div>';
                        $reset_dsp = ' style="display:none;"';
                    }
                    ?>
                </div>
                
                <div class="ipbe-image-field">
                    <div class="ipbe-select-image">
                        <p class="mt0"><?php _e( 'Select an image using the button below.', 'wp_profit_page_creator' ); ?></p>
                        <a class="ipbe-btn ipbe-btn-primary ipbe-btn-media ipbe-btn-sm" name="select_image" data-choose="<?php esc_attr_e( 'Choose Preview Content Image' ); ?>"
                          data-update="<?php esc_attr_e( 'Choose image' ); ?>">
                            <i class="ibe ibe-image"></i>
                            <?php _e( 'Select Image', 'wp_profit_page_creator' ); ?>
                        </a>
                        <a class="ipbe-btn ipbe-btn-reset ipbe-btn-sm" href="#"<?php echo $reset_dsp; ?>>
                            <i class="ibe ibe-ban"></i>
                            <?php _e( 'Clear Image', 'wp_profit_page_creator' ); ?>
                        </a>
                    </div>
                    <input type="hidden" name="upload_type" class="ipbe-upload-type" value="offer_thumbnail_image" />
                    <input type="hidden" name="offer_thumbnail_image" class="ipbe-image-id" value="<?php echo $attach_id; ?>" />
                </div>
            </div>
            
                    <p><?php _e( 'Or add the image URL', 'wp_profit_page_creator' ); ?></p>
                    <input type="text" id="input-offer-thumbnail-url" class="ipbe-input ipbe-input-full" name="offer_thumbnail_url" value="<?php echo $setting->getSetting( 'offer_thumbnail_url' ); ?>">
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines thumbnail image of the offer.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Offer Info
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-info"><?php _e( 'Offer Info', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <textarea id="input-offer-info" class="ipbe-input ipbe-input-full" name="offer_info"><?php echo stripslashes( $setting->getSetting( 'offer_info' )); ?></textarea>
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines info of the offer.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Call to action Info
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-action-info"><?php _e( 'Call to Action Info', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <textarea id="input-offer-action-info" class="ipbe-input ipbe-input-full" name="offer_action_info"><?php echo stripslashes( $setting->getSetting( 'offer_action_info' )); ?></textarea>
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines action info of the offer.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //URL
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-url"><?php _e( 'URL', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <input type="text" id="input-offer-url" class="ipbe-input ipbe-input-full" name="offer_url" value="<?php echo $setting->getSetting( 'offer_url' ); ?>">
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines detail URL of the offer.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Button Label
            ?>
            <div class="ipbe-field-row ipbe-field-x ipbe-help-abs">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-button-label"><?php _e( 'Button Label', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    <input type="text" id="input-offer-button-label" class="ipbe-input ipbe-input-full" name="offer_button_label" value="<?php echo $setting->getSetting( 'offer_button_label' ); ?>">
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines the label of the detail button.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Button Style
            ?>
            <div class="ipbe-field-row ipbe-field-x">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-button-style"><?php _e( 'Button Style', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    
                    <select name="offer_button_style" id="input-box-shadow">
                        <?php
                        $current = $setting->getSetting( 'offer_button_style', 'grey' );
                        $styles  = array(
                            'grey'    => __( 'Grey', 'wp_profit_page_creator' ),
                            'black'   => __( 'Black', 'wp_profit_page_creator' ),
                            'blue'    => __( 'Blue', 'wp_profit_page_creator' ),
                            'light-blue' => __( 'Light Blue', 'wp_profit_page_creator' ),
                            'green'   => __( 'Green', 'wp_profit_page_creator' ),
                            'orange'  => __( 'Orange', 'wp_profit_page_creator' ),
                            'red'     => __( 'Red', 'wp_profit_page_creator' )
                        );
                        foreach( $styles as $key => $label ) {
                            $sltd = '';
                            if ( $key == $current ) {
                                $sltd = ' selected="selected"';
                            }
                            echo '<option value="' . $key . '"' . $sltd .'>'. $label .'</option>';
                        }
                        ?>
                    </select>
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Determines the style of the detail button.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Open in new tab
            ?>
            <div class="ipbe-field-row ipbe-field-x">
                <div class="ipbe-form-label col-lg-3 col-md-4 col-sm-12">
                    <label for="input-offer-open"><?php _e( 'Open in New Tab Window', 'wp_profit_page_creator' ); ?></label>
                </div>
                <div class="ipbe-field col-lg-9 col-md-8 col-sm-12">
                    
                    <div class="ipbe-btn-onoff">
                        <?php
                        $val = $setting->getSetting( 'offer_open', 'true' );
                        if ( $val == 'false' ) {
                            $clon  = '';
                            $cloff = ' ipbe-btn-danger active';
                        } else {
                            $clon  = ' ipbe-btn-success active';
                            $cloff = '';
                        }
                        ?>
                        <div class="ipbe-btn-group">
                            <button data-value="true" class="ipbe-btn<?php echo $clon; ?> ipbe-btn-on" type="button"><?php _e( 'On', 'wp_profit_page_creator' ); ?></button>
                            <button data-value="false" class="ipbe-btn<?php echo $cloff; ?> ipbe-btn-off" type="button"><?php _e( 'Off', 'wp_profit_page_creator' ); ?></button>
                        </div>
                        <input type="hidden" class="ipbe-onoff-value" name="offer_open" value="<?php echo $val; ?>" />
                    </div>
                    
                    <div class="ipbe-help">
                        <a class="ipbe-btn-help ipbe-btn ipbe-btn-default" href="#"><i class="ibe ibe-question"></i></a>
                        <div class="ipbe-help-content ipbe-hide">
                            <?php _e( 'Decides whether to open a new window or not when the user pressed the detail button.', 'wp_profit_page_creator' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php
            //Submit Button
            ?>
            <div class="ipbe-field-row ipbe-field-y">
                <div class="row">
                    <div class="col-md-6">
                        <button type="submit" class="ip-form-submit ipbe-btn ipbe-btn-primary" id="<?php echo $submitId; ?>" name="add_offer">
                            <i class="ibe ibe-<?php echo $submit_icon; ?>"></i>
                            <strong><?php echo $submit; ?></strong>
                        </button>
                    </div>
                    <div class="col-md-6">
                        <div class="text-right">
                            <a href="#" class="ipbe-btn ipbe-ui-close ipbe-modal-cancel">
                                <i class="ibe ibe-times"></i>
                                <?php _e( 'Cancel', 'wp_profit_page_creator' ); ?>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
        }
        
        /**
         * Show content admin setting
         *
         * @return void
         */
        public function setting()
        {
        ?>
            <div id="ipprof-setting" class="wrap ipbe-wrap ipprof-admin">
                <div class="ipbe-inner">
                    
                    <?php $this->_header( 'ipprof-setting' ); ?>
                    
                    <div class="ipbe-main">
                        <div class="ipbe-main-info"></div>
                        
                        <div class="ipbe-primary">
                            <div class="ipprof-setting-wrap">
                                <?php
                                $action = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipprof=1&action=ipprof_setting';
                                ?>
                                <form id="ipprof-form-setting" class="ipbe-form" action="<?php echo $action; ?>" method="post">
                                    
                                    <?php
                                    $path = get_option( '__ipprof_base_path', 'profit' );
                                    ?>
                                    <div class="container-fluid container">
                                        <div class="mb40">
                                            <h3 class="font-h4 mb20 line-title-double"><?php _e( 'Permalink', 'wp_profit_page_creator' ); ?></h3>
                                            <p><?php _e( 'Set the base path permalink for all your profit pages through the following input:', 'wp_profit_page_creator' ); ?></p>
                                            <div class="fields">
                                                <div class="ipbe-field-row ipbe-field-x">
                                                    <div class="ipbe-form-label col-lg-2 col-md-3 col-sm-4">
                                                        <label for="input-base-path"><?php _e( 'Base Path Permalink', 'wp_profit_page_creator' ); ?></label>
                                                    </div>
                                                    <div class="ipbe-field col-lg-3 col-md-5 col-sm-6">

                                                        <input type="text" id="input-base-path" class="ipbe-input ipbe-input-full" name="base_path" value="<?php echo $path; ?> ">
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <div class="ipbe-form-footer">
                                        <div class="container-fluid container">
                                            <div class="col-xs-6">
                                                <button type="submit" id="" class="ipbe-btn ipbe-btn-primary ipbe-btn-lg ip-form-submit">
                                                    <i class="ibe ibe-floppy-o"></i>
                                                    <?php _e( 'Save Settings', 'wp_profit_page_creator' ); ?>
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                    
                </div>
                
            </div>
            
        <?php
        }
        
        /**
         * Admin header template
         *
         * @param string $page
         * @return void
         */
        protected function _header( $page, $title = '', $info = '', $icon = '' )
        {
            $struct = array(
                'ipprof' => array(
                    'title'     => __( 'Dashboard', 'wp_profit_page_creator' ),
                    'info'      => __( 'See all profit page and manage it', 'wp_profit_page_creator' ),
                    'icon'      => 'dashboard'
                ),
                'ipprof-add' => array(
                    'title'     => __( 'Add Profit Page', 'wp_profit_page_creator' ),
                    'info'      => __( 'Add new profit page', 'wp_profit_page_creator' ),
                    'icon'      => 'plus-circle'
                ),
                'ipprof-setting' => array(
                    'title'     => __( 'Settings', 'wp_profit_page_creator' ),
                    'info'      => __( 'Set general settings for profit page on your website', 'wp_profit_page_creator' ),
                    'icon'      => 'cog'
                )
            );
        ?>
            <div class="ipbe-top">
                <div class="ipbe-header">
                    <div class="ipbe-page-title">
                        <h1>
                            <i class="ibe ibe-money"></i>
                            <span>
                                <strong><span>WP</span> Profit Page Creator</strong>
                                <em><?php _e( 'WordPress plugin to create profit page', 'wp_profit_page_creator' ); ?></em>
                            </span>
                        </h1>
                    </div>
                </div>
                <div class="ipbe-nav">
                    <ul>
                    <?php
                    if ( array_key_exists( $page, $struct ))
                    {
                        if ( empty( $title )) {
                            $title = $struct[$page]['title'];
                        }
                        if ( empty( $info )) {
                            $info  = $struct[$page]['info'];
                        }
                        if ( empty( $icon )) {
                            $icon  = $struct[$page]['icon'];
                        }
                    }
                    foreach( $struct as $name => $data ) 
                    {
                        $active = '';
                        if ( $page == $name ) {
                            $active = ' class="active"';
                        }
                        echo '<li' . $active . '>' .
                                '<a href="admin.php?page=' . $name . '">' .
                                    '<i class="ibe ibe-' . $data['icon'] . '"></i>' .
                                    $data['title'] .
                                '</a>' .
                            '</li>';
                    }
                    ?>
                    </ul>
                </div>
                <div class="ipbe-page-info">
                    <i class="ibe ibe-<?php echo $icon; ?>"></i>
                    <div class="ipbe-info">
                        <h2><?php echo $title; ?></h2>
                        <h3><?php echo $info; ?></h3>
                    </div>
                </div>
            </div>
        <?php
        }
        
        /**
         * Get profit object
         *
         * @return array
         */
        protected function _get_profit_object()
        {
            $args = array(
                'orderby'        => 'post_title',
                'order'          => 'DESC', 
                'post_type'      => 'ipprof-item',
                'post_status'    => array('publish'),
                'posts_per_page' => -1,
                'paged'          => 1
            );
            $query  = new WP_Query;
            $profits = $query->query( $args );
            return $profits;
        }
    }
}